@@ -5,7 +5,7 @@
 modname = 'cubicweb_celery'
 distname = 'cubicweb-celery'
 
-numversion = (0, 5, 0)
+numversion = (1, 0, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -15,9 +15,8 @@ description = 'Celery cube'
 web = 'https://forge.extranet.logilab.fr/cubicweb/cubes/%s' % distname
 
 __depends__ = {
-    'cubicweb': ">= 3.24, < 3.36.0",
-    'six': '>= 1.4.0',
-    'celery': '>=4,<5',
+    'celery': '~=5.0',
+    'cubicweb': ">= 3.24, < 3.38.0",
 }
 __recommends__ = {}
 
